@@ -53,7 +53,7 @@ class Kfzcheck(object):
     searchparameter = optionen.searchparameter
 
     def load(self):
-        csvfile = 'kfzliste.csv' # add here your file path 
+        csvfile = '/opt/kfzcheck/kfzliste.csv' # add here your file path 
         try: # check if the file is readable
             file = csv.reader(open(csvfile), delimiter=',') # parse the csv file
             return file 
